---
title: <span class="badge builder"></span> HeatmapCalculationOptions
---
# <span class="badge builder"></span> HeatmapCalculationOptions

## Constructor

```python
HeatmapCalculationOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.HeatmapCalculationOptions
```

### <span class="badge object-method"></span> x_buckets

The number of buckets to use for the xAxis in the heatmap

```python
def x_buckets(x_buckets: cogbuilder.Builder[common.HeatmapCalculationBucketConfig]) -> typing.Self
```

### <span class="badge object-method"></span> y_buckets

The number of buckets to use for the yAxis in the heatmap

```python
def y_buckets(y_buckets: cogbuilder.Builder[common.HeatmapCalculationBucketConfig]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [HeatmapCalculationOptions](./object-HeatmapCalculationOptions.md)
